Improve this Doc

# `ngMockE2E`

## Installation

First, get the file:

- Google CDN e.g.

      "//ajax.googleapis.com/ajax/libs/angularjs/X.Y.Z/angular-mocks.js"

- NPM e.g.

      npm install --save angular-mocks@X.Y.Z

  or

      yarn add angular-mocks@X.Y.Z

- Bower e.g.

      bower install angular-mocks#X.Y.Z

- code.angularjs.org (discouraged for production use) e.g.

      "//code.angularjs.org/X.Y.Z/angular-mocks.js"

where X.Y.Z is the AngularJS version you are running.

Then, include `angular-mocks.js` in your HTML:

    <script src="path/to/angular.js"></script>
    <script src="path/to/angular-mocks.js"></script>

Finally, load the module in your application by adding it as a dependent module:

    angular.module('app', ['ngMockE2E']);

With that you're ready to get started!

The `ngMockE2E` is an angular module which contains mocks suitable for end-to-end testing. Currently there is only one mock present in this module - the e2e $httpBackend mock.

## Module Components

### Service

Name | Description
--- | ---
$httpBackend | Fake HTTP backend implementation suitable for end-to-end testing or backend-less development of applications that use the $http service.